#
# Indirect GNU makefile for ethernet interface library
#

include ../GNUmake.config		# for pattern rules

# This builds machine-dependent components for the ethernet interface library

# Compilation flags used

ifeq ($(findstring gcc,$(CC)),)

CFLAGS = $(OPT) $(DEFINES)

else

CFLAGS = $(OPTG) $(DEFINES)

endif

# VPATH directives

vpath %.h ../src
vpath %.c ../src

# Configuration

NIT := $(shell ls /usr/include/net/nit.h 2>/dev/null)
NIT4 := $(shell ls /dev/nit 2>/dev/null)

# Software components

HDRS = ether.h libether.h

SRCS = etherints.c etherblock.c

ALLSRCS := $(SRCS) nitaddr.c nit4open.c nit4read.c nit3open.c dliopen.c

ifneq ($(NIT4),)
SRCS := $(SRCS) nitaddr.c nit4open.c nit4read.c
else
ifneq ($(NIT),)
SRCS := $(SRCS) nitaddr.c nit3open.c
endif
endif

ifneq ($(findstring ultrix,$(SYSTEM)),)
SRCS := $(SRCS) dliopen.c
override CC=cc
endif

OBJS = $(SRCS:.c=.o)


# Default dependency - remake all out of date object files

.PHONY: default all

default: all

all: libether.a

libether.a: $(OBJS)
ifeq ($(findstring t,$(MAKEFLAGS)),)
	ar curv $@ $(OBJS)
	ranlib $@
else
	@echo $(MAKE) > /dev/null
	touch $@
	ranlib -t $@
endif

$(OBJS): $(HDRS)


# Fluff test

.PHONY: lint noise

lint: $(SRCS)
	-lint -abux $?

noise: $(SRCS)
	-lint -abuhx $?


# Vgrind formatted listing

LISTS = $(ALLSRCS:.c=.ps) $(HDRS:.h=.ps) index.ps

.PHONY: listing

listing: index $(LISTS)

index.ps: index
	sort -fu -o index index
	$(VGRIND) -t -x index > index.ps

index: /dev/null
	ctags -tv $(SRCS) $(HDRS) >> index 2>/dev/null


# Utility operations

.PHONY: clean cleanlists realclean

clean:
	rm -f $(OBJS) libether.a

cleanlists:
	rm -f $(LISTS) index

realclean: clean cleanlists
